//
//  XMLParser.m
//  WeatherParser
//
//  Created by kelley.ricker on 12/16/15.
//  Copyright © 2015 GrapeCity. All rights reserved.
//

#import "XMLParser.h"
#import "WeatherData.h"
#import "FetchWeatherData.h"

@implementation XMLParser
-(id)initWithArray: (NSMutableArray *) array{
    self = [super init];
    if (self) {
        self.array = array;
    }
    return self;
}
-(void) parseDataFor:(FlexChart *) chart{
    [FetchWeatherData placeXMLGetRequest:@"15232" withHandler:^(NSData *data, NSURLResponse *response, NSError *error) {
        [self setDateFormat];
        self.parser = [[NSXMLParser alloc] initWithData:data];
        self.parser.delegate = self;
        [self.parser parse];
        
        dispatch_async(dispatch_get_main_queue(), ^{

            chart.itemsSource = self.array;
        });
    }];
}
-(void)parser:(NSXMLParser *)parser didStartElement:(NSString *)elementName namespaceURI:(NSString *)namespaceURI qualifiedName:(NSString *)qName attributes:(NSDictionary<NSString *,NSString *> *)attributeDict{
    self.element = elementName;
    self.attributes = attributeDict;
    if ([self.element isEqual: @"time"]) {
        self.currentDate = [self.dateFormatter dateFromString:(NSString *)self.attributes[@"from"]];
    }
    else if ([self.element isEqual: @"symbol"]) {
        self.currentWeatherDescription = self.attributes[@"name"];
    }
    else if ([self.element isEqual: @"temperature"]) {
        self.currentHighTemp = self.attributes[@"max"];
        self.currentLowTemp = self.attributes[@"min"];
    }
    else if ([self.element isEqual: @"pressure"]) {
        self.currentPressure = self.attributes[@"value"];
    }
    else if ([self.element isEqual: @"humidity"]) {
        self.currentHumidity = self.attributes[@"value"];
        WeatherData *forecast = [[WeatherData alloc] initWithDate:self.currentDate weatherDescription:self.currentWeatherDescription highTemp:self.currentHighTemp lowTemp:self.currentLowTemp humidity:self.currentHumidity pressure:self.currentPressure];
        [self.array addObject:forecast];
    }

}

-(void)setDateFormat {
    self.dateFormatter = [[NSDateFormatter alloc] init];
    [self.dateFormatter setDateFormat:@"yyyy'-'MM'-'dd'T'HH':'mm':'ss"];
}
-(void)parser:(NSXMLParser *)parser foundCharacters:(NSString *)string{
    if ([self.element isEqual: @"time"]) {
        self.currentDate = [self.dateFormatter dateFromString:(NSString *)self.attributes[@"from"]];
    }
}
-(void)parser:(NSXMLParser *)parser didEndElement:(NSString *)elementName namespaceURI:(NSString *)namespaceURI qualifiedName:(NSString *)qName{
    self.element = nil;
}
@end
